@@ -50,13 +50,13 @@ class Article(DeclarativeBase):
 
     uid = Column(Integer, autoincrement=True, primary_key=True)
     title = Column(Unicode(150), nullable=False, default=u"Untitled", index=True)
-    published = Column(Integer, nullable=False, default=0)
+    published = Column(Integer, nullable=False, default=0, index=True)
     private = Column(Integer, nullable=False, default=0)
 
     author_id = Column(Integer, ForeignKey(primary_key(app_model.User)))
     author = relation(app_model.User, backref=backref('articles'))
 
-    blog_id = Column(Integer, ForeignKey(primary_key(Blog)), nullable=True)
+    blog_id = Column(Integer, ForeignKey(primary_key(Blog)), nullable=True, index=True)
     blog = relation(Blog, backref=backref('articles'), lazy='joined')
 
     publish_date = Column(DateTime, nullable=False, default=datetime.now)
@@ -185,4 +185,4 @@ class Attachment(DeclarativeBase):
         return self.content.url
 
 if sqla_events:
-    event.listen(Attachment, 'before_delete', Attachment.delete_file)
\ No newline at end of file
+    event.listen(Attachment, 'before_delete', Attachment.delete_file)
